@@ -77,7 +77,7 @@ class CartItem(BaseModel):
 
     @validator("product")
     def not_more_than_255(cls, v, field):
-        if len(v) > 255:
+        if v and len(v) > 255:
             raise ValueError(f"{field} can't be more than 255 characters")
         return v
 
@@ -175,11 +175,34 @@ class PaymentInitPostData(BaseModel):
     class Config:
         arbitrary_types_allowed = True
 
+    @validator(
+        "ship_name",
+        "ship_add1",
+        "ship_city",
+        "ship_postcode",
+        "ship_country",
+        always=True,
+    )
+    def validate_based_on_shipping_method(cls, v, field, values):
+        shipping = values["shipping_method"] == ShippingMethodEnum.YES
+        if shipping:
+            if not v:
+                raise ValueError(
+                    f"{field} should be provided if shipping_method set to 'YES'"
+                )
+            elif len(v) > 50:
+                raise ValueError(f"{field} can't be more than 50 characters")
+        if not shipping and v:
+            raise ValueError(
+                f"{field} should be omitted if shipping_method not set to 'YES'"
+            )
+        return v
+
     @validator(
         "currency",
     )
     def not_more_than_three(cls, v, field):
-        if len(v) > 3:
+        if v and len(v) > 3:
             raise ValueError(f"{field} can't be more than 3 characters")
         return v
 
@@ -193,7 +216,7 @@ class PaymentInitPostData(BaseModel):
         "country_topup",
     )
     def not_more_than_thirty(cls, v, field):
-        if len(v) > 30:
+        if v and len(v) > 30:
             raise ValueError(f"{field} can't be more than 30 characters")
         return v
 
@@ -206,30 +229,25 @@ class PaymentInitPostData(BaseModel):
         "cus_city",
         "cus_state",
         "cus_country",
-        "ship_name",
-        "ship_add1",
         "ship_add2",
-        "ship_city",
         "ship_state",
-        "ship_country",
-        "ship_postcode",
         "pnr",
         "hotel_city",
     )
     def not_more_than_fifty(cls, v, field):
-        if len(v) > 50:
+        if v and len(v) > 50:
             raise ValueError(f"{field} can't be more than 50 characters")
         return v
 
     @validator("product_profile", "product_category")
     def not_more_than_hundred(cls, v, field):
-        if len(v) > 100:
+        if v and len(v) > 100:
             raise ValueError(f"{field} can't be more than 100 characters")
         return v
 
     @validator("topup_number")
     def not_more_than_hundred_fifty(cls, v, field):
-        if len(v) > 150:
+        if v and len(v) > 150:
             raise ValueError(f"{field} can't be more than 150 characters")
         return v
 
@@ -248,7 +266,7 @@ class PaymentInitPostData(BaseModel):
         "value_d",
     )
     def not_more_than_255(cls, v, field):
-        if len(v) > 255:
+        if v and len(v) > 255:
             raise ValueError(f"{field} can't be more than 255 characters")
         return v
 
@@ -282,26 +300,6 @@ class PaymentInitPostData(BaseModel):
             )
         return v
 
-    @validator(
-        "ship_name",
-        "ship_add1",
-        "ship_city",
-        "ship_postcode",
-        "ship_country",
-        always=True,
-    )
-    def validate_based_on_shipping_method(cls, v, field, values):
-        shipping = values["shipping_method"] == ShippingMethodEnum.YES
-        if shipping and not v:
-            raise ValueError(
-                f"{field} should be provided if shipping_method set to 'YES'"
-            )
-        if not shipping and v:
-            raise ValueError(
-                f"{field} should be omitted if shipping_method not set to 'YES'"
-            )
-        return v
-
     @validator(
         "hours_till_departure",
         "flight_type",
@@ -491,7 +489,7 @@ class OrderValidationPostData(BaseModel):
 
     @validator("val_id")
     def not_more_than_fifty(cls, v, field):
-        if len(v) > 50:
+        if v and len(v) > 50:
             raise ValueError(f"{field} can't be more than 50 characters")
         return v
 
@@ -525,19 +523,19 @@ class RefundRequestPostData(BaseModel):
         "refe_id",
     )
     def not_more_than_fifty(cls, v, field):
-        if len(v) > 50:
+        if v and len(v) > 50:
             raise ValueError(f"{field} can't be more than 50 characters")
         return v
 
     @validator("bank_tran_id")
     def not_more_than_eighty(cls, v, field):
-        if len(v) > 80:
+        if v and len(v) > 80:
             raise ValueError(f"{field} can't be more than 80 characters")
         return v
 
     @validator("refund_remarks")
     def not_more_than_255(cls, v, field):
-        if len(v) > 255:
+        if v and len(v) > 255:
             raise ValueError(f"{field} can't be more than 255 characters")
         return v
 
